@@ -15,9 +15,10 @@ class Request:
     :ivar interval: Interval in seconds between each aggregation.
     :ivar filters: Filter to apply on the query (not yet fully implemented).
     :ivar connections: Connections rules between equipment to align data in time (not yet fully implemented).
+    :ivar null: By default at 'drop' and dropping NaN values. If not intended behavior please set it to 'ignore' or 'all'.
     """
 
-    def __init__(self):
+    def __init__(self, null='drop'):
         self.function = None
         self.equipments = []
         self.start = None
@@ -33,6 +34,7 @@ class Request:
         self.target_feat = None
         self.connections = None
         self.name = None
+        self.null = null
 
     def prepare(self):
         """
@@ -59,6 +61,8 @@ class Request:
             }
         else:
             raise KeyError("Missing aggregations information inside the request")
+        if self.null is not None and self.null != 'drop':
+            query['null'] = self.null
         return query
 
     def __format_date(self, dt_to_format):
@@ -191,6 +195,9 @@ class Request:
         if "connections" in json_data.keys():
             self.connections = json_data["connections"]
 
+        if "null" in json_data.keys():
+            self.null = json_data["null"]
+
         if "target_feat" in json_data.keys():
             self.target_feat = json_data["target_feat"]
             if "sensor" not in self.target_feat.keys():
