@@ -197,9 +197,9 @@ class WizataDSAPIClient:
                                         headers=self.__header()
                                         )
             if response.status_code == 200:
-                obj = None
-                for obj in response.json():
-                    obj.from_json(response.json())
+                obj = Experiment()
+                for obj_json in response.json():
+                    obj.from_json(obj_json)
                 return obj
             else:
                 raise self.__raise_error(response)
@@ -213,9 +213,9 @@ class WizataDSAPIClient:
                                         headers=self.__header()
                                         )
             if response.status_code == 200:
-                obj = None
-                for obj in response.json():
-                    obj.from_json(response.json())
+                obj = MLModel()
+                for obj_json in response.json():
+                    obj.from_json(obj_json)
                 return obj
             else:
                 raise self.__raise_error(response)
@@ -520,7 +520,7 @@ class WizataDSAPIClient:
             if isinstance(experiment, uuid.UUID):
                 execution.experiment_id = experiment
             elif isinstance(experiment, str):
-                execution.experiment_id = uuid.UUID(experiment)
+                execution.experiment_id = self.get(experiment_key=experiment).experiment_id
             elif isinstance(experiment, Experiment):
                 execution.experiment_id = experiment.experiment_id
 
